====================
Universe / Portfolio
====================

Universe
--------

.. autosummary::
    :toctree: api/

    prismstudio.list_universe
    prismstudio.filter_universe
    prismstudio.delete_universe
    prismstudio.get_universe
    prismstudio.rename_universe
    prismstudio.upload_timeseries_universe
    prismstudio.upload_timerange_universe
    prismstudio.combine_universe
    prismstudio.get_universe_template
    prismstudio.save_index_as_universe


Portfolio
---------

.. autosummary::
    :toctree: api/

    prismstudio.list_portfolio
    prismstudio.delete_portfolio
    prismstudio.get_portfolio
    prismstudio.rename_portfolio
    prismstudio.save_index_as_portfolio